==> xfce4-power-manager-1.3.0.tar.bz2: xfce4-power-manager-1.3.0/common/xfpm-icons.h <==
/*
 * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __XFPM_ICONS_H
#define __XFPM_ICONS_H

G_BEGIN_DECLS

#define XFPM_AC_ADAPTER_ICON			"xfpm-ac-adapter"

#define XFPM_UPS_ICON				"xfpm-ups-100"
#define XFPM_KBD_ICON				"xfpm-keyboard-100"
#define XFPM_MOUSE_ICON				"xfpm-mouse-100"
#define XFPM_PHONE_ICON				"xfpm-phone-100"
#define XFPM_PDA_ICON				"xfpm-pda-100"

#define XFPM_PRIMARY_ICON_PREFIX		"xfpm-primary-"
#define XFPM_UPS_ICON_PREFIX			"xfpm-ups-"
#define XFPM_MOUSE_ICON_PREFIX			"xfpm-mouse-"
#define XFPM_KBD_ICON_PREFIX			"xfpm-keyboard-"
#define XFPM_PDA_ICON_PREFIX			"xfpm-pda-"
#define XFPM_PHONE_ICON_PREFIX			"xfpm-phone-"
#define XFPM_MEDIA_PLAYER_PREFIX        "xfpm-mediaplayer-"
#define XFPM_MONITOR_PREFIX             "xfpm-monitor-"
#define XFPM_COMPUTER_ICON_PREFIX       "xfpm-computer-"
#define XFPM_TABLET_ICON_PREFIX         "xfpm-tablet-"

#define XFPM_DISPLAY_BRIGHTNESS_ICON	        "xfpm-brightness-lcd"
#define XFPM_DISPLAY_BRIGHTNESS_INVALID_ICON	"xfpm-brightness-lcd-missing" /* When no hw found */

G_END_DECLS

#endif

==> xfce4-power-manager_1.4.4.orig.tar.bz2: xfce4-power-manager-1.4.4/common/xfpm-icons.h <==
/*
 * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __XFPM_ICONS_H
#define __XFPM_ICONS_H

G_BEGIN_DECLS

#define XFPM_AC_ADAPTER_ICON			"xfpm-ac-adapter"

#define XFPM_UPS_ICON				"xfpm-ups-100"
#define XFPM_KBD_ICON				"input-keyboard"
#define XFPM_MOUSE_ICON				"input-mouse"
#define XFPM_PHONE_ICON				"phone"
#define XFPM_PDA_ICON				"pda"

#define XFPM_PRIMARY_ICON_PREFIX		"xfpm-primary-"
#define XFPM_UPS_ICON_PREFIX			"xfpm-ups-"
#define XFPM_MOUSE_ICON_PREFIX			"input-mouse"
#define XFPM_KBD_ICON_PREFIX			"input-keyboard"
#define XFPM_PDA_ICON_PREFIX			"pda"
#define XFPM_PHONE_ICON_PREFIX			"phone"
#define XFPM_MEDIA_PLAYER_PREFIX        "multimedia-player"
#define XFPM_MONITOR_PREFIX             "video-display"
#define XFPM_COMPUTER_ICON_PREFIX       "computer"
#define XFPM_TABLET_ICON_PREFIX         "tablet"

#define XFPM_DISPLAY_BRIGHTNESS_ICON	        "xfpm-brightness-lcd"
#define XFPM_DISPLAY_BRIGHTNESS_INVALID_ICON	"xfpm-brightness-lcd-missing" /* When no hw found */

G_END_DECLS

#endif
